@@ -1,4 +1,11 @@
-#define SQUID_UNIT_TEST 1
+/*
+ * Copyright (C) 1996-2015 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #define SQUID_HELPER 1
 
 #include "squid.h"
@@ -6,6 +13,7 @@
 #include <cppunit/TestAssert.h>
 
 #include "testIcmp.h"
+#include "unitTestMain.h"
 
 CPPUNIT_TEST_SUITE_REGISTRATION( testIcmp );
 
@@ -108,3 +116,4 @@ testIcmp::testHops()
 }
 
 #endif /* USE_ICMP */
+
